@@ -83,27 +83,12 @@ class GQLHandler:
         # execute QUERY|MUTATION
         data = gqlClient.execute(query=query, variables=variables)
         return data
-    async def runGqlQuery_a(self, query: str, variables):
-        if query == None:
-            raise Exception("GraphQL guery string MUST NOT be empty!")
-        # Add Xplora® API headers
-        requestHeaders = self.getRequestHeaders("application/json; charset=UTF-8")
-        # create GQLClient
-        gqlClient = GraphqlClient(endpoint=self.ENDPOINT, headers=requestHeaders)
-        # execute QUERY|MUTATION
-        data = await gqlClient.execute_async(query=query, variables=variables)
-        return data
 
     def runAuthorizedGqlQuery(self, query: str, variables):
         if self.accessToken == None:
             raise Exception("You have to login to the Xplora® API first.")
         # Run GraphQL query and return
         return self.runGqlQuery(query, variables)
-    async def runAuthorizedGqlQuery_a(self, query: str, variables):
-        if self.accessToken == None:
-            raise Exception("You have to login to the Xplora® API first.")
-        # Run GraphQL query and return
-        return await self.runGqlQuery_a(query, variables)
 
     def login(self):
         data = self.runGqlQuery(gm.MUTATION["tokenM"], self.variables)['data']
@@ -165,9 +150,6 @@ class GQLHandler:
     def getWatchLastLocation(self, ownId):
         return self.runAuthorizedGqlQuery(gq.QUERY['watchLastLocateQ'], { "uid": ownId })['data']
 
-    async def getWatchLastLocation_a(self, ownId):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['watchLastLocateQ'], { "uid": ownId }))['data']
-
     def trackWatch(self, ownId): # tracking time - seconds
         res = self.runAuthorizedGqlQuery(gq.QUERY['trackWatchQ'], { "uid": ownId })['data']
         if res['trackWatch'] != None:
@@ -180,12 +162,6 @@ class GQLHandler:
             return res
         return { 'askWatchLocate': False }
 
-    async def askWatchLocate_a(self, ownId):
-        res = (await self.runAuthorizedGqlQuery_a(gq.QUERY['askWatchLocateQ'], { "uid": ownId }))['data']
-        if res['askWatchLocate'] != None:
-            return res
-        return { 'askWatchLocate': False }
-
     def getAlarms(self, ownId):
         return self.runAuthorizedGqlQuery(gq.QUERY['alarmsQ'], { "uid": ownId })['data']
 
